@@ -6,7 +6,7 @@
 #						 All Rights Reserved.
 #
 
-RCS_ID =  '$Id: http_server.py,v 1.26.4.2 2001/07/02 19:45:22 shane Exp $'
+RCS_ID =  '$Id: http_server.py,v 1.26.4.4 2001/10/10 13:49:27 stevea Exp $'
 
 # python modules
 import os
@@ -165,7 +165,7 @@ class http_request:
     def response (self, code=200):
         message = self.responses[code]
         self.reply_code = code
-        return 'HTTP/%s %d %s' % (self.version, code, message)
+        return 'HTTP/%s %d %s' % (self.version or '1.0', code, message)
         
     def error (self, code):
         self.reply_code = code
@@ -713,7 +713,7 @@ def get_header_match (head_reg, lines):
             return m
     return ''
     
-REQUEST = re.compile ('([^ ]+) ([^ ]+)(( HTTP/([0-9.]+))$|$)')
+REQUEST = re.compile ('([^ ]+) (?:[^ :?#]+://[^ ?#/]*)?([^ ]+)(( HTTP/([0-9.]+))$|$)')
 
 def crack_request (r):
     m = REQUEST.match (r)
