@@ -33,7 +33,7 @@
   USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
   DAMAGE.
 
-  $Id: Acquisition.c,v 1.51 2001/03/28 14:06:50 jeremy Exp $
+  $Id: Acquisition.c,v 1.51.36.1 2001/09/14 20:05:59 shane Exp $
 
   If you have questions regarding this software,
   contact:
@@ -1050,28 +1050,39 @@ Wrapper_acquire_method(Wrapper *self, PyObject *args, PyObject *kw)
 static PyObject *
 Wrapper_inContextOf(Wrapper *self, PyObject *args)
 {
-  PyObject *o, *c;
+  PyObject *subob, *o, *c;
   int inner=1;
 
   UNLESS(PyArg_ParseTuple(args,"O|i",&o,&inner)) return NULL;
 
   if (inner) {
+    /* subob = self */
+    subob = OBJECT(self);
+
     /* o = aq_base(o) */
     while (isWrapper(o) && WRAPPER(o)->obj) o=WRAPPER(o)->obj;
 
     /* while 1: */
     while (1) {
 
-      /*   if aq_base(self) is o: return 1 */
-      c = self->obj;
+      /*   if aq_base(subob) is o: return 1 */
+      c = subob;
       while (isWrapper(c) && WRAPPER(c)->obj) c = WRAPPER(c)->obj;
       if (c == o) return PyInt_FromLong(1);
 
-      /*   self = aq_parent(aq_inner(self)) */
+      /*   self = aq_inner(subob) */
       /*   if self is None: break */
-      while (self->obj && isWrapper(self->obj)) self = WRAPPER(self->obj);
-      if (self->container && isWrapper(self->container))
-        self = WRAPPER(self->container);
+      if (isWrapper(subob)) {
+        self = WRAPPER(subob);
+        while (self->obj && isWrapper(self->obj))
+          self = WRAPPER(self->obj);
+      }
+      else break;
+
+      /*   subob = aq_parent(self) */
+      /*   if subob is None: break */
+      if (self->container)
+        subob = self->container;
       else break;
     }
   }
@@ -1427,7 +1438,7 @@ void
 initAcquisition(void)
 {
   PyObject *m, *d;
-  char *rev="$Revision: 1.51 $";
+  char *rev="$Revision: 1.51.36.1 $";
   PURE_MIXIN_CLASS(Acquirer,
     "Base class for objects that implicitly"
     " acquire attributes from containers\n"
@@ -1446,7 +1457,7 @@ initAcquisition(void)
   /* Create the module and add the functions */
   m = Py_InitModule4("Acquisition", methods,
 	   "Provide base classes for acquiring objects\n\n"
-	   "$Id: Acquisition.c,v 1.51 2001/03/28 14:06:50 jeremy Exp $\n",
+	   "$Id: Acquisition.c,v 1.51.36.1 2001/09/14 20:05:59 shane Exp $\n",
 		     OBJECT(NULL),PYTHON_API_VERSION);
 
   d = PyModule_GetDict(m);
