@@ -82,7 +82,7 @@
   
  ****************************************************************************/
 
-#define BUCKETTEMPLATE_C "$Id: BucketTemplate.c,v 1.17 2001/06/20 19:47:00 matt Exp $\n"
+#define BUCKETTEMPLATE_C "$Id: BucketTemplate.c,v 1.17.2.3 2001/11/02 17:26:44 jeremy Exp $\n"
 
 /*
 ** _bucket_get
@@ -95,6 +95,8 @@
 **
 ** Returns:	object	matching object or 0/1 object
 */
+
+
 static PyObject *
 _bucket_get(Bucket *self, PyObject *keyarg, int has_key)
 {
@@ -110,6 +112,8 @@ _bucket_get(Bucket *self, PyObject *keyarg, int has_key)
   for (min=0, max=self->len, i=max/2, l=max; i != l; l=i, i=(min+max)/2)
     {
       cmp=TEST_KEY(self->keys[i], key);
+      if (PyErr_Occurred()) goto err;
+
       if (cmp < 0) min=i;
       else if (cmp == 0)
 	{
@@ -129,6 +133,8 @@ _bucket_get(Bucket *self, PyObject *keyarg, int has_key)
   PER_ACCESSED(self);
   if (has_key) return PyInt_FromLong(0);
   PyErr_SetObject(PyExc_KeyError, keyarg);
+
+err:
   return NULL;
 }
 
@@ -332,59 +338,69 @@ bucket_setitem(Bucket *self, PyObject *key, PyObject *v)
   return 0;
 }
 
+/**
+ ** Mapping_update()
+ **
+ ** Accepts a sequence of 2-tuples or any object with an items()
+ ** method that returns a sequence of 2-tuples.
+ **
+ */
+
 static PyObject *
 Mapping_update(PyObject *self, PyObject *args)
 {
-  PyObject *seq=0, *o, *t, *v, *tb, *k;
+  PyObject *seq=0, *o, *t, *v, *tb, *k, *items = NULL;
   int i, ind;
 
   UNLESS(PyArg_ParseTuple(args, "|O:update", &seq)) return NULL;
 
-  if (seq)
+  if (!seq)
     {
-
-      if (PySequence_Check(seq))
-        {
-          Py_INCREF(seq);
-        }
-      else
-        {
-          seq=PyObject_GetAttr(seq, items_str);
-          UNLESS(seq) return NULL;
-          ASSIGN(seq, PyObject_CallObject(seq, NULL));
-          UNLESS(seq) return NULL;
-        }
-
-      for (i=0; ; i++)
-        {
-          UNLESS (o=PySequence_GetItem(seq, i))
-            {
-              PyErr_Fetch(&t, &v, &tb);
-              if (t != PyExc_IndexError)
-                {
-                  PyErr_Restore(t, v, tb);
-                  goto err;
-                }
-              Py_XDECREF(t);
-              Py_XDECREF(v);
-              Py_XDECREF(tb);
-              break;
-            }
-          ind=PyArg_ParseTuple(o, "OO;items must be 2-item tuples", &k, &v);
-          if (ind)
-            ind = PyObject_SetItem(self, k, v);
-          else
-            ind=-1;
-          Py_DECREF(o);
-          if (ind < 0) goto err;
-        }
+      Py_INCREF(Py_None);
+      return Py_None;
+    }
+    
+  if (!PySequence_Check(seq))
+    {
+      items = PyObject_GetAttr(seq, items_str);
+      UNLESS(items) return NULL;
+      ASSIGN(items, PyObject_CallObject(items, NULL));
+      UNLESS(items) return NULL;
+      /* items is DECREFed on exit, seq is not */
+      seq = items;
     }
 
+  for (i=0; ; i++)
+    {
+      o = PySequence_GetItem(seq, i);
+      UNLESS (o)
+	{
+	  PyErr_Fetch(&t, &v, &tb);
+	  if (t != PyExc_IndexError)
+	    {
+	      PyErr_Restore(t, v, tb);
+	      goto err;
+	    }
+	  Py_XDECREF(t);
+	  Py_XDECREF(v);
+	  Py_XDECREF(tb);
+	  break;
+	}
+      ind = PyArg_ParseTuple(o, "OO;items must be 2-item tuples", &k, &v);
+      if (ind)
+	ind = PyObject_SetItem(self, k, v);
+      else
+	ind = -1;
+      Py_DECREF(o);
+      if (ind < 0) goto err;
+    }
+
+  Py_XDECREF(items);
   Py_INCREF(Py_None);
   return Py_None;
 
  err:
-  Py_DECREF(seq);
+  Py_XDECREF(items);
   return NULL;
 }
 
@@ -686,7 +702,7 @@ bucket_values(Bucket *self, PyObject *args)
 
   for (i=low; i <= high; i++)
     {
-      COPY_KEY_TO_OBJECT(v, self->keys[i]);
+      COPY_VALUE_TO_OBJECT(v, self->values[i]);
       UNLESS (v) goto err;
       if (PyList_SetItem(r, i, v) < 0) goto err;
     }
