@@ -82,14 +82,8 @@
 # attributions are listed in the accompanying credits file.
 # 
 ##############################################################################
-import sys, os, time, whrandom
-
-try:
-    sys.path.insert(0, '.')
-    import ZODB
-except:
-    sys.path.insert(0, '../..')
-    import ZODB
+import sys, os, time, random
+import os, sys
 
 from BTrees.OOBTree import OOBTree, OOBucket, OOSet, OOTreeSet
 from BTrees.IOBTree import IOBTree, IOBucket, IOSet, IOTreeSet
@@ -98,7 +92,6 @@ from BTrees.OIBTree import OIBTree, OIBucket, OISet, OITreeSet
 from unittest import TestCase, TestSuite, TextTestRunner, makeSuite
 
 from glob import glob
-import os
 
 class Base:
     """ Tests common to all types: sets, buckets, and BTrees """
@@ -208,7 +201,7 @@ class MappingBase(Base):
         added = {}
         r = range(1000)
         for x in r:
-            k = whrandom.choice(r)
+            k = random.choice(r)
             self.t[k] = x
             added[k] = x
         addl = added.keys()
@@ -220,12 +213,11 @@ class MappingBase(Base):
 
     def testValuesWorks(self):
         for x in range(100):
-            self.t[x] = x
+            self.t[x] = x*x
         v = self.t.values()
-        i = 0
-        for x in v:
-            assert x == i, (x,i)
-            i = i + 1
+        for i in range(100):
+            assert v[i]==i*i , (i*i,i)
+
             
     def testKeysWorks(self):
         for x in range(100):
@@ -276,7 +268,7 @@ class MappingBase(Base):
     def testClear(self):
         r = range(100)
         for x in r:
-            rnd = whrandom.choice(r)
+            rnd = random.choice(r)
             self.t[rnd] = 0
         self.t.clear()
         diff = lsubtract(list(self.t.keys()), [])
@@ -287,7 +279,7 @@ class MappingBase(Base):
         d={}
         l=[]
         for i in range(10000):
-            k=whrandom.randint(-2000, 2000)
+            k=random.randrange(-2000, 2001)
             d[k]=i
             l.append((k, i))
             
@@ -396,7 +388,7 @@ class NormalSetTests(Base):
         d={}
         l=[]
         for i in range(10000):
-            k=whrandom.randint(-2000, 2000)
+            k=random.randrange(-2000, 2001)
             d[k]=i
             l.append(k)
             
@@ -502,7 +494,7 @@ class BTreeTests(MappingBase):
         added = {}
         r = range(100)
         for x in r:
-            k = whrandom.choice(r)
+            k = random.choice(r)
             if not added.has_key(k):
                 self.t[k] = x
                 added[k] = 1
@@ -515,7 +507,7 @@ class BTreeTests(MappingBase):
         added = {}
         r = range(100)
         for x in r:
-            k = whrandom.choice(r)
+            k = random.choice(r)
             self.t[k] = x
             added[k] = 1
         addl = added.keys()
@@ -527,12 +519,12 @@ class BTreeTests(MappingBase):
         r = range(1000)
         added = []
         for x in r:
-            k = whrandom.choice(r)
+            k = random.choice(r)
             self.t[k] = x
             added.append(k)
         deleted = []
         for x in r:
-            k = whrandom.choice(r)
+            k = random.choice(r)
             if self.t.has_key(k):
                 del self.t[k]
                 deleted.append(k)
@@ -547,7 +539,7 @@ class BTreeTests(MappingBase):
     def testTargetedDeletes(self):
         r = range(1000)
         for x in r:
-            k = whrandom.choice(r)
+            k = random.choice(r)
             self.t[k] = x
         for x in r:
             try:
@@ -634,7 +626,7 @@ class BTreeTests(MappingBase):
         r = range(100)
         a = {}
         for x in r:
-            rnd = whrandom.choice(r)
+            rnd = random.choice(r)
             self.t[rnd] = 0
             a[rnd] = 0
         diff = lsubtract(list(self.t.keys(0, 100)), a.keys())
@@ -815,15 +807,6 @@ def test_suite():
 
     return alltests
 
-def main():
-    alltests=test_suite()
-    runner = TextTestRunner(verbosity=2)
-    runner.run(alltests)
-
-def debug():
-   test_suite().debug()
-    
-
 ## utility functions
 
 def lsubtract(l1, l2):
@@ -836,9 +819,3 @@ def lsubtract(l1, l2):
 def realseq(itemsob):
     return map(lambda x: x, itemsob)
 
-if __name__=='__main__':
-   if len(sys.argv) > 1:
-      globals()[sys.argv[1]]()
-   else:
-      main()
-
