@@ -83,17 +83,16 @@
 # 
 ##############################################################################
 __doc__="""Copy interface"""
-__version__='$Revision: 1.72.2.2 $'[11:-2]
+__version__='$Revision: 1.72.2.4 $'[11:-2]
 
 import sys, string, Globals, Moniker, tempfile, ExtensionClass
 from marshal import loads, dumps
 from urllib import quote, unquote
 from zlib import compress, decompress
 from App.Dialogs import MessageDialog
-from AccessControl import getSecurityManager
+from AccessControl import getSecurityManager, Unauthorized
 from Acquisition import aq_base, aq_inner, aq_parent
 
-
 CopyError='Copy Error'
 
 _marker=[]
