@@ -84,7 +84,7 @@
 ##############################################################################
 """DTML Method objects."""
 
-__version__='$Revision: 1.67 $'[11:-2]
+__version__='$Revision: 1.67.2.4 $'[11:-2]
 
 import History
 from Globals import HTML, DTMLFile, MessageDialog
@@ -180,6 +180,11 @@ class DTMLMethod(RestrictedDTML, HTML, Acquisition.Implicit, RoleManager,
 
         security=getSecurityManager()
         security.addContext(self)
+        if self.__dict__.has_key('validate'):
+            first_time_through = 0
+        else:
+            self.__dict__['validate'] = security.DTMLValidate
+            first_time_through = 1
         try:
         
             if client is None:
@@ -197,7 +202,10 @@ class DTMLMethod(RestrictedDTML, HTML, Acquisition.Implicit, RoleManager,
                     self.ZCacheable_set(r)
                 return r
 
-        finally: security.removeContext(self)
+        finally:
+            security.removeContext(self)
+            if first_time_through:
+                del self.__dict__['validate']
 
         have_key=RESPONSE.headers.has_key
         if not (have_key('content-type') or have_key('Content-Type')):
@@ -211,6 +219,9 @@ class DTMLMethod(RestrictedDTML, HTML, Acquisition.Implicit, RoleManager,
             self.ZCacheable_set(result)
         return result
 
+    def validate(self, inst, parent, name, value, md=None):
+        return getSecurityManager().validate(inst, parent, name, value)
+
     def ZDocumentTemplate_beforeRender(self, md, default):
         # Tries to get a cached value.
         if self._cache_namespace_keys:
