@@ -84,9 +84,9 @@
 ##############################################################################
 __doc__="""Object Manager
 
-$Id: ObjectManager.py,v 1.137.4.6 2001/07/05 19:09:08 brian Exp $"""
+$Id: ObjectManager.py,v 1.137.4.7 2001/10/26 15:14:09 andreasjung Exp $"""
 
-__version__='$Revision: 1.137.4.6 $'[11:-2]
+__version__='$Revision: 1.137.4.7 $'[11:-2]
 
 import App.Management, Acquisition, Globals, CopySupport, Products
 import os, App.FactoryDispatcher, re, Products
@@ -109,7 +109,7 @@ customImporters={
     XMLExportImport.magic: XMLExportImport.importXML,
     }
 
-bad_id=re.compile(r'[^a-zA-Z0-9-_~,.$# ]').search #TS
+bad_id=re.compile(r'[^a-zA-Z0-9-_~,.$#\(\) ]').search #TS
 
 # Global constants: __replaceable__ flags:
 NOT_REPLACEABLE = 0
