@@ -84,7 +84,7 @@
 ##############################################################################
 
 """Property sheets"""
-__version__='$Revision: 1.74.4.5 $'[11:-2]
+__version__='$Revision: 1.74.4.7 $'[11:-2]
 
 import time, string, App.Management, Globals
 from webdav.WriteLockInterface import WriteLockInterface
@@ -364,9 +364,9 @@ class PropertySheet(Traversable, Persistent, Implicit):
             name, type=item['id'], item.get('type','string')
             value=self.getProperty(name)
             if type=='tokens':
-                value=join(value, ' ')
+                value=join(str(value), ' ')
             elif type=='lines':
-                value=join(value, '\n')
+                value=join(str(value), '\n')
             # check for xml property
             attrs=item.get('meta', {}).get('__xml_attrs__', None)
             if attrs is not None:
@@ -376,7 +376,11 @@ class PropertySheet(Traversable, Persistent, Implicit):
                 # Quote non-xml items here?
                 attrs='' 
 
-            prop='  <n:%s%s>%s</n:%s>' % (name, attrs, xml_escape(value), name)
+            if hasattr(self,"dav__"+name):
+                prop='  <n:%s%s>%s</n:%s>' % (name, attrs, value, name)
+            else:
+                prop='  <n:%s%s>%s</n:%s>' % \
+                    (name, attrs, xml_escape(value), name)
 
             result.append(prop)
         if not result: return ''
@@ -414,9 +418,9 @@ class PropertySheet(Traversable, Persistent, Implicit):
             name, type=item['id'], item.get('type','string')
             value=self.getProperty(name)
             if type=='tokens':
-                value=join(value, ' ')
+                value=join(str(value), ' ')
             elif type=='lines':
-                value=join(value, '\n')
+                value=join(str(value), '\n')
             # allow for xml properties
             attrs=item.get('meta', {}).get('__xml_attrs__', None)
             if attrs is not None:
@@ -815,9 +819,7 @@ def xml_escape(v):
     to entities to keep the properties XML compliant. 
     """
     v = str(v)
-    
-    if v.count('<') != v.count('>'): 
-        v = v.replace('<','&lt;')
-        v = v.replace('>','&gt;')
-
+    v = v.replace('&', '&amp;')
+    v = v.replace('<', '&lt;')
+    v = v.replace('>', '&gt;')
     return  unicode(v,"latin-1").encode("utf-8")
