@@ -362,6 +362,7 @@ class Catalog(Persistent, Acquisition.Implicit, ExtensionClass.Base):
         del indexes[name]
         self.indexes = indexes
 
+
     # the cataloging API
 
     def catalogObject(self, object, uid, threshold=None,idxs=[]):
@@ -668,7 +669,9 @@ class Catalog(Persistent, Acquisition.Implicit, ExtensionClass.Base):
                 if (type(so) is type('') and
                     lower(so) in ('reverse', 'descending')):
                     r.reverse()
-                r=LazyCat(map(lambda i: i[1], r), len(r))
+
+                r=map(lambda i: i[1], r)
+                r=LazyCat(r, reduce(lambda x,y: x+len(y), r, 0))
 
         return r
 
