@@ -368,11 +368,12 @@ class DocumentClass:
     #'doc_underline'
     text_types = [
         'doc_sgml',
-        'doc_href',
+        'doc_href1',
+        'doc_href2',
         'doc_strong',
         'doc_emphasize',
-        'doc_underline',
         'doc_literal',
+        'doc_underline',
         'doc_sgml',
         'doc_xref',
         ]
@@ -902,7 +903,7 @@ class DocumentClass:
                 return None
             else:
                 # the .. is somewhere else, ignore it
-                return (StructuredTextInnerLink(s[start2+1,end2-1],start2,end2))
+                return (StructuredTextInnerLink(s[start2+1:end2-1],start2,end2))
             return None
         elif expr2(s) and not expr1(s):
             start,end = expr2(s).span()
@@ -924,7 +925,7 @@ class DocumentClass:
     def doc_underline(self,
                       s,
                       #expr=re.compile(r"\_([a-zA-Z0-9\s\.,\?]+)\_").search, # old expr, inconsistent punc, failed to cross newlines
-                      expr=re.compile(r'_([%s%s%s\s]+)_' % (letters, digits, under_punc)).search):
+                      expr=re.compile(r'_([%s%s%s\s]+)_[\s%s]' % (letters, digits, under_punc,phrase_delimiters)).search):
 
         result = expr(s)
         if result:
@@ -932,7 +933,7 @@ class DocumentClass:
                return None # no double unders
             start,end = result.span(1)
             st,e = result.span()
-            return (StructuredTextUnderline(s[start:end]),st,e)
+            return (StructuredTextUnderline(s[start:end]),st,e-1)
         else:
             return None
     
@@ -955,13 +956,22 @@ class DocumentClass:
     _ABS_AND_RELATIVE_URL=r'([%s0-9_\@\.\,\?\!\/\:\;\-\#\~\=\&\%%]+)' % letters
 
     _SPACES = r'(\s*)'
-    
-    def doc_href(self, s,
-                 expr1 = re.compile(_DQUOTEDTEXT + "(:)" + _ABS_AND_RELATIVE_URL + _SPACES).search,
-                 expr2 = re.compile(_DQUOTEDTEXT + r'(\,\s+)' + _ABSOLUTE_URL + _SPACES).search):
-        
-        punctuation = re.compile(r"[\,\.\?\!\;]+").match
-        r=expr1(s) or expr2(s)
+
+
+    def doc_href1(self, s,
+                  expr=re.compile(_DQUOTEDTEXT + "(:)" + _ABS_AND_RELATIVE_URL + _SPACES).search
+                   ):
+        return self.doc_href(s, expr)
+
+    def doc_href2(self, s,
+                  expr=re.compile(_DQUOTEDTEXT + r'(\,\s+)' + _ABSOLUTE_URL + _SPACES).search
+                   ):
+         return self.doc_href(s, expr)
+
+
+    def doc_href(self, s, expr, punctuation=re.compile(r"[\,\.\?\!\;]+").match):
+
+        r=expr(s)
 
         if r:
             # need to grab the href part and the
