@@ -85,7 +85,7 @@
 
 """WebDAV support - null resource objects."""
 
-__version__='$Revision: 1.29.4.2 $'[11:-2]
+__version__='$Revision: 1.29.4.4 $'[11:-2]
 
 import sys, os, string, mimetypes, Globals, davcmds
 import Acquisition, OFS.content_types
@@ -131,7 +131,7 @@ class NullResource(Persistent, Acquisition.Implicit, Resource):
         raise 'Not Found', 'The requested resource does not exist.'
 
     # Most methods return 404 (Not Found) for null resources.
-    DELETE=OPTIONS=TRACE=PROPFIND=PROPPATCH=COPY=MOVE=HEAD
+    DELETE=TRACE=PROPFIND=PROPPATCH=COPY=MOVE=HEAD
 
     def _default_PUT_factory( self, name, typ, body ):
         #   Return DTMLDoc/Image/File, based on sniffing.
@@ -315,7 +315,11 @@ class LockNullResource(NullResource, OFS.SimpleItem.Item_w__name__):
     title_or_id__roles__=None
     def title_or_id(self):
         return 'Foo'
-    
+
+    def PROPFIND(self, REQUEST, RESPONSE):
+        """Retrieve properties defined on the resource."""
+        return Resource.PROPFIND(self, REQUEST, RESPONSE)
+
     def LOCK(self, REQUEST, RESPONSE):
         """ A Lock command on a LockNull resource should only be a
         refresh request (one without a body) """
